pub struct MutationPlugin { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world mutation-plugin.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
MutationPlugin::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
MutationPluginPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesMutationPluginPre::instantiateto create aMutationPlugin. -
If you’ve instantiated the instance yourself already then you can use
MutationPlugin::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl MutationPlugin
impl MutationPlugin
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MutationPlugin>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<MutationPlugin>
Convenience wrapper around MutationPluginPre::new and
MutationPluginPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<MutationPlugin>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<MutationPlugin>
Convenience wrapper around MutationPluginIndices::new and
MutationPluginIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MutationPlugin>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MutationPlugin>where
_T: Send,
Convenience wrapper around MutationPluginPre::new and
MutationPluginPre::instantiate_async.
pub fn ryo_transform_types(&self) -> &Guest
pub fn ryo_transform_mutation(&self) -> &Guest